# jingbao-fuwuqi

# introduction

This script checks in a loop for server availability. It provides a visual and verbal alert on detection of availability. This script has been tested on Ubuntu 16.04.

# quick start

```Bash
sudo apt-get -y install festival
sudo pip install jingbao_fuwuqi
jingbao_fuwuqi.py
```
